// Persistence of Vision Ray Tracer Scene Description File
// File:  SL Heli Chopper 02.pov
// Vers:  3.5
// Date:
// Auth:  Sven Littkowski
//        Jamaica, West Indies
//        E-MAILs: jamaica_sven@yahoo.com 
//                 sven@jamaica-focus.com
//        Tel.:    +1 - 876 - 792 22 22     
//
// About: My persistence of the vision of a small ultra-light helicoper, featuring
//        a small engine and made of fiber glass (the case) and plexi glass (for the canopy).
//        Note the two conter-rotating rotors beside each other. 
//        This helicopter could carry, as concepted with this file, one adult normally and 
//        probably another one in some cases, or some light freight beside the pilot.
// About: I just like to play out my ideas and visions. Living in Jamaica with it's bad roads,
//        the idea just came naturally to me. It's also because the imagination of such a small
//        flight module enthusiasts me a lot, personally. I have a series of those little flight
//        modules (all different types and concepts) and should, maybe, open soon a "fair", 
//        a virtual showground, an exhibition. In preparation is a set of different options and
//        textures to enable decisions what purpose this HeliChopper will be rendered for (police,
//        army, navy, traffic control, etc.).

#include "Farben.inc"
#include "textures.inc"
#include "Glass.inc"
#include "Skins.inc"
//#include "SL Human Man Afro Bald 01.inc"       
//#include "SL Human Man Afro Bald 02.inc"
//#include "SL Human Woman Afro Long 01.inc"       
//#include "SL Athmospheres.inc"

#declare Photons=off;                 // on or off. Light special effects. Requires more render time.
#declare Radiosity=on;               // on or off. Interaction between elements. Requires more render time.
#declare LeftDoorOpenAngle=00;       // Should be between 0 to 70  (no negative values needed)
#declare RightDoorOpenAngle=00;      // Should be between 0 to 70  (no negative values needed)
#declare Cut_It=off;                 // To see the inside construction
#declare Zeit=17;                    // 00..24        The time of the day, 0 to 12 equals to AM times, 13 equals to 1 PM, 14 equals to 2 PM, etc. 0 and 24 is the same time.

global_settings 
{
 assumed_gamma 1.0      
 #if (Radiosity) 
  radiosity
  {
   pretrace_start 0.04           
   pretrace_end   0.04           
   count 35                      
   nearest_count 5              
   error_bound 1.8              
   recursion_limit 3            
   low_error_factor .5          
   gray_threshold 0.0           
   minimum_reuse 0.015          
   brightness 1                 
   adc_bailout 0.01/2
   normal on                   
   media on                    
   always_sample off           
   max_sample 1.0             
  }      
 #end
 #if (Photons)         /* */ 
  photons 
  {
   spacing 0.01         
   media 0.5, 1.5  
   jitter 1.0               
   expand_thresholds 0.2, 40
//   save_file "SL Heli Chopper 02 - Gray - Alone.ptn"   
//   save_file "SL Heli Chopper 02 - Gray - Fleet on Ground.ptn"   
//   load_file "SL Heli Chopper 02 - Gray - Alone.ptn"   
//   load_file "SL Heli Chopper 02 - Gray - Fleet on Ground.ptn"   
  } 
 #end                            
}  

light_source 
{
 < -1000.0, 1000.0, -1000.0 >
 #switch(Zeit)
  #range(00,04)
   color MidnightBlue        
  #break 
  #case(05)
   color SandyBrown        
  #break 
  #case(06)
   color rgb < 0.7, 0.5, 0.3 >        
  #break 
  #case(07)
   color MediumWood        
  #break 
  #case(08)
   color rgb < 1.0, 0.9, 0.7 >        
  #break 
  #case(09)
   color White        
  #break 
  #case(10)
   color White        
  #break 
  #case(11)
   color White        
  #break 
  #case(12)
   color White        
  #break 
  #case(13)
   color White        
  #break 
  #case(14)
   color White        
  #break 
  #case(15)
   color White        
  #break 
  #case(16)
   color rgb < 1.0, 0.9, 0.7 >        
  #break 
  #case(17)
   color rgb < 0.8, 0.7, 0.5 >        
  #break 
  #case(18)
   color rgb < 0.8, 0.6, 0.3 >        
  #break 
  #case(19)
   color rgb < 0.5, 0.2, 0.0 >        
  #break 
  #range(20,24)
   color MidnightBlue        
  #break 
 #end 
 area_light
 < 500, 0, 0 > < 0, 0, 500 >
 4, 4         
 adaptive 0
 jitter         
 circular    
 orient     
 photons    
 {  
  refraction on
  reflection on
 }
}

camera 
{
// location  < -0.0, 1.7, -6.0 >     // Single
// look_at   < -0.0, 1.7,  0.0 >
// location  < -0.0, 0.5, -6.0 >     // Single on Ground
// look_at   < +0.5, 0.5,  0.0 >
// location  < -10.0, 2.7, -16.0 >     // Fleet
// look_at   < -0.0, 2.7,  0.0 >
 location  < -15.0, 1.5, -16.0 >     // Fleet low perspective
 look_at   < -0.0, 1.0,  0.0 >
// location  < 0.0, 11.2, 0.6 >     // Flight
// look_at   < 0.0, 10.5, 10.0 >
}    

#declare Halb = texture
{  
 gradient x
 texture_map
 {
  [ 0.0 pigment { Gray10 } finish { crand 0.1 } ]
  [ 0.5 pigment { Gray10 } finish { crand 0.1 } ]
  [ 0.5 pigment { White } finish { Glossy } ]
  [ 1.0 pigment { White } finish { Glossy } ]
 }
 scale 6.0
 translate < -3.3, 0.0, 0.0 >
}  

#declare BlattV = texture
{  
 gradient x
 texture_map
 {
  [ 0.0 pigment { White } finish { Glossy } ]
  [ 0.5 pigment { White } finish { Glossy } ]
  [ 0.5 pigment { Gray20 } finish { Glossy } ]
  [ 0.9 pigment { Gray20 } finish { Glossy } ]
  [ 0.9 pigment { Gray30 } finish { Glossy } ]
  [ 1.0 pigment { Gray30 } finish { Glossy } ]
 }
 scale 6.0
 translate < -3.3, 0.0, 0.0 >
}

#declare RumpfLinks = texture
{
 pigment
 {  
  gradient y
  pigment_map 
  {
   [ 0.00 Gray95 ]
   [ 0.20 Gray95 ]
   [ 0.20 Gray95 ]
   [ 0.75 Gray30 ]
   [ 0.75 Gray30 ]
   [ 1.00 Gray30 ]
  }
  translate < 0.0, -0.7, 0.0 >
  scale 3.0 
  rotate < 0.0, 0.0, 5.0 >
 }
 finish { Glossy }
} 
texture
{
 pigment { image_map { png "HeliChopper2JF.png" once filter 0 1.0 } }
 finish { Glossy }  
 scale 0.7
 translate < 1.3, -0.4, 0.0 >
}  
texture
{
 pigment { image_map { png "HeliChopper2GrayEntrance.png" once filter 0 0.0 } }
 finish { Glossy }  
 scale < 0.9, 0.36, 1.0 > 
 scale 0.3
 translate < -1.1, -0.8, 0.0 >
}   
texture
{
 pigment { image_map { png "HeliChopper2GrayRotorAngles.png" once filter 0 1.0 } }
 finish { Glossy }  
 scale 1.2
 translate < -0.65, -0.63, 0.0 >
}        

#declare RumpfRechts = texture
{
 pigment
 {  
  gradient y
  pigment_map 
  {
   [ 0.00 Gray95 ]
   [ 0.20 Gray95 ]
   [ 0.20 Gray95 ]
   [ 0.75 Gray30 ]
   [ 0.75 Gray30 ]
   [ 1.00 Gray30 ]
  }
  translate < 0.0, -0.7, 0.0 >
  scale 3.0 
  rotate < 0.0, 0.0, 5.0 >
 }
 finish { Glossy }
}    
texture
{
 pigment { image_map { png "HeliChopper2JF.png" once filter 0 1.0 } }
 finish { Glossy }
 translate < -0.5, 0.0, 0.0 >  
 rotate < 0.0, 180.0, 0.0 >  
 translate < 0.5, 0.0, 0.0 >  
 scale 0.7
 translate < 1.3, -0.4, 0.0 >
}   
texture
{
 pigment { image_map { png "HeliChopper2GrayEntrance.png" once filter 0 0.0 } }
 finish { Glossy }  
 translate < -0.5, 0.0, 0.0 >  
 rotate < 0.0, 180.0, 0.0 >  
 translate < 0.5, 0.0, 0.0 >  
 scale < 0.9, 0.36, 1.0 >
 scale 0.3
 translate < -1.1, -0.8, 0.0 >
}    
texture
{
 pigment { image_map { png "HeliChopper2GrayRotorAngles.png" once filter 0 1.0 } }
 finish { Glossy }  
 scale 1.2
 translate < -0.65, -0.63, 0.0 >
}     


#declare Eingang = cylinder 
{
 < 0.0, 0.0, -5.5 > < 0.0, 0.0, 5.5 > 0.5 
 scale < 0.7, 1.4, 1.0 > 
 rotate < 0.0, 0.0, -30.0 > 
 translate < -1.3, -0.3, 0.0 > 
}
 
#declare Eingang1 = cylinder 
{
 < 0.0, 0.0, -5.5 > < 0.0, 0.0, 5.5 > 0.47 
 scale < 0.7, 1.4, 1.0 > 
 rotate < 0.0, 0.0, -30.0 > 
 translate < -1.3, -0.3, 0.0 > 
}
 
#declare EingangNegativ = difference
{  
 box { < -9.0, -9.0, -9.0 > < 9.0, 9.0, 9.0 > }
 object { Eingang }
} 

#declare EingangNegativ1 = difference
{  
 box { < -9.0, -9.0, -9.0 > < 9.0, 9.0, 9.0 > }
 object { Eingang1 }
} 

#declare Glasses = material
{      
 texture { Glass finish { F_Glass7 } }           // 1, 3, 7
 interior { I_Glass_Exp(2) fade_color Clear }
}       

#declare InnenRumpf = difference
{  
 box { < -5.0, -5.0, -5.0 > < 5.0, 5.0, 5.0 > }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.995 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.995 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.995 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.995 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.995 rotate < 0.0, 0.0, 20.0 > }
 }
}

#declare AussenRumpf = blob 
{
 threshold 0.6
 sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.995 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
 cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.995 }
 cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.995 } 
 sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.995 rotate < 0.0, 0.0, 20.0 > }
 sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.995 rotate < 0.0, 0.0, 20.0 > }
}

#declare GlasRumpf1 = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99999 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99999 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99999 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99999 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99999 rotate < 0.0, 0.0, 20.0 > }
 }  
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.991 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.991 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.991 }
  sphere { < 0.0, 0.35, -1.95 > 0.5, 0.3 scale 0.991 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.5, 0.3 scale 0.991 rotate < 0.0, 0.0, 20.0 > }
 }
 sphere 
 { 
  < 0.0, 0.0, 0.0 >, 0.93 
  scale < 1.5, 1.0, 1.3 > 
  rotate < 0.0, 0.0, 20.0 > 
  translate < -1.0, -0.5, 0.0 > 
 }
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > } 
 #if (Cut_It)
  box { < -5.0, -5.0, -5.0 > < 5.0, 5.0, 0.0 > pigment { White } } 
 #end
 material { Glasses texture { pigment { rgbf < 0.0, 0.0, 0.0, 0.7 > } finish { reflection 0.00 } } }
 photons    
 {  
  target 1.0
  refraction on
  reflection on
 }  
}

#declare GlasRumpf = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99999 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99999 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99999 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99999 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99999 rotate < 0.0, 0.0, 20.0 > }
 }  
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.991 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.991 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.991 }
  sphere { < 0.0, 0.35, -1.95 > 0.5, 0.3 scale 0.991 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.5, 0.3 scale 0.991 rotate < 0.0, 0.0, 20.0 > }
 }
 sphere 
 { 
  < 0.0, 0.0, 0.0 >, 0.93 
  scale < 1.5, 1.0, 1.3 > 
  rotate < 0.0, 0.0, 20.0 > 
  translate < -1.0, -0.5, 0.0 > 
 }
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > } 
 object { Eingang }
 #if (Cut_It)
  box { < -5.0, -5.0, -5.0 > < 5.0, 5.0, 0.0 > pigment { White } } 
 #end
 material { Glasses texture { pigment { rgbf < 0.0, 0.0, 0.0, 0.7 > } finish { reflection 0.00 } } }
 photons    
 {  
  target 1.0
  refraction on
  reflection on
 }  
}

#declare PlastikRumpfLinks1 = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  texture { RumpfLinks }
 }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99 }
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  texture { Halb }
 }
 sphere 
 { 
  < -1.5, -0.2, 0.0 >, 1.3 
  pigment { Gray10 }
 }                     
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 0.0 > < 5.0, 5.0, 5.0 > pigment { White } } 
}   

#declare PlastikRumpfLinks2 = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  texture { RumpfLinks }
 }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99 }
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  texture { Halb }
 }
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 0.0 > < 5.0, 5.0, 5.0 > pigment { White } } 
}   

#declare PlastikRumpfLinks = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  texture { RumpfLinks }
 }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99 }
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  texture { Halb }
 }
 sphere 
 { 
  < -1.5, -0.2, 0.0 >, 1.3 
  pigment { Gray10 }
 }                     
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 0.0 > < 5.0, 5.0, 5.0 > pigment { White } } 
 object { Eingang }
}   

#declare PlastikRumpfRechts1 = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  texture { RumpfRechts }
 }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99 }
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  texture { Halb }
 }
 sphere 
 { 
  < -1.5, -0.2, 0.0 >, 1.3 
  pigment { Gray10 }
 }                     
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > pigment { Gray20 } } 
 box { < -5.0, -5.0, -5.0 > < 5.0, 5.0, 0.0 > pigment { White } }
} 

#declare PlastikRumpfRechts2 = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  texture { RumpfRechts }
 }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99 }
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  texture { Halb }
 }
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > pigment { Gray20 } } 
 box { < -5.0, -5.0, -5.0 > < 5.0, 5.0, 0.0 > pigment { White } }
} 

#declare PlastikRumpfRechts = difference
{
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 } 
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 rotate < 0.0, 0.0, 20.0 > }
  texture { RumpfRechts }
 }
 blob 
 {
  threshold 0.6
  sphere { < 0.0, 0.0, 0.0 >, 2.0, 1.0 scale 0.99 scale < 1.5, 1.0, 1.3 > rotate < 0.0, 0.0, 20.0 > translate < -1.0, -0.5, 0.0 > }
  cylinder { < 0.0, 0.0, -1.3 > < 0.0, 0.0, 1.3 > 1.0, 1.0 scale 0.99 }
  cylinder { < 0.0, -0.2, 0.0 > < 2.0, -0.2, 0.0 > 1.5, 1.0 scale 0.99 }
  sphere { < 0.0, 0.35, -1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  sphere { < 0.0, 0.35, 1.95 > 0.55, 0.3 scale 0.99 rotate < 0.0, 0.0, 20.0 > }
  texture { Halb }
 }
 sphere 
 { 
  < -1.5, -0.2, 0.0 >, 1.3 
  pigment { Gray10 }
 }                     
 box { < -5.0, -5.0, -1.43 > < 5.0, 5.0, -1.42 > pigment { Gray20 } } 
 box { < -5.0, -5.0, 1.42 > < 5.0, 5.0, 1.43 > pigment { Gray20 } } 
 box { < -5.0, -5.0, -5.0 > < 5.0, 5.0, 0.0 > pigment { White } }
 object { Eingang }
} 

#declare TuerRahmenRechts = difference
{
 object { PlastikRumpfRechts2 scale 1.001 }
 object { EingangNegativ }
 object { Eingang1 }         //
 box { < -9.0, -9.0, -9.0 > < 9.0, 9.0, 0.0 > pigment { Black } finish { Glossy } } 
}

#declare TuerRechts1 = difference
{
 union
 {
  object { PlastikRumpfRechts1 scale 1.00 }
  object { GlasRumpf1 scale 1.00 }
 }
 object { EingangNegativ1 }
 box { < -9.0, -9.0, -9.0 > < 9.0, 9.0, 0.0 > pigment { Black } finish { Glossy } } 
}

#declare TuerRechts = union
{
 union
 {
  object { TuerRechts1 scale 1.00 }
  object { TuerRahmenRechts }
  cylinder { < -1.10, -0.5, 1.20 > < -1.10, -0.5, 1.25 > 0.05 pigment { Gray20 } finish { Dull crand 0.2 } }
 }
 translate < 1.3, 0.3, -0.95 > 
 rotate < 0.0, 0.0, 30.0 >     
 translate < 0.35, 0.0, 0.0 > 
 
 #if (RightDoorOpenAngle<0) #declare RightDoorOpenAngle=(RightDoorOpenAngle*(-1));
 #end
 #if (RightDoorOpenAngle>70) #declare LeftDoorOpenAngle=70;
 #end
 rotate < 0.0, (RightDoorOpenAngle*(-1)), 0.0 >         
 
 translate < -0.35, 0.0, 0.0 > 
 rotate < 0.0, 0.0, -30.0 >     
 translate < -1.3, -0.3, 0.95 > 
}

#declare TuerRahmenLinks = difference
{
 object { PlastikRumpfLinks2 scale 1.001 }
 object { EingangNegativ }
 object { Eingang1 }    
 box { < -9.0, -9.0, 0.0 > < 9.0, 9.0, 9.0 > pigment { Black } finish { Glossy } }
}

#declare TuerLinks1 = difference
{
 union
 {
  object { PlastikRumpfLinks1 scale 1.00 }
  object { GlasRumpf1 scale 1.00 } 
 }
 object { EingangNegativ1 }
 box { < -9.0, -9.0, 0.0 > < 9.0, 9.0, 9.0 > pigment { Black } finish { Glossy } }
}   

#declare TuerLinks = union
{
 union
 {
  object { TuerLinks1 scale 1.00 }
  object { TuerRahmenLinks }
  cylinder { < -1.10, -0.5, -1.25 > < -1.10, -0.5, -1.20 > 0.05 pigment { Gray20 } finish { Dull crand 0.2 } }
 }
 translate < 1.3, 0.3, 0.95 > 
 rotate < 0.0, 0.0, 30.0 >     
 translate < 0.35, 0.0, 0.0 > 
 
 #if (LeftDoorOpenAngle<0) #declare LeftDoorOpenAngle=(LeftDoorOpenAngle*(-1));
 #end
 #if (LeftDoorOpenAngle>70) #declare LeftDoorOpenAngle=70;
 #end
 rotate < 0.0, (LeftDoorOpenAngle*(1)), 0.0 >         
 
 translate < -0.35, 0.0, 0.0 > 
 rotate < 0.0, 0.0, -30.0 >     
 translate < -1.3, -0.3, -0.95 > 
}        

#declare TuerScharnier = union
{
 cylinder 
 { 
  < -0.35, -0.1, 0.0 > < -0.35, 0.1, 0.0 > 0.025  
  rotate < 20.0, 0.0, -30.0 >
  translate < -1.3, -0.3, -0.97 > 
 }
 
 cylinder 
 { 
  < -0.35, -0.1, 0.0 > < -0.35, 0.1, 0.0 > 0.025  
  rotate < -20.0, 0.0, -30.0 >
  translate < -1.3, -0.3, 0.97 > 
 }   
 translate < -0.10, -0.2, 0.0 >
 pigment { Gray50 } 
 finish { Glossy } 
} 

#declare PlastikRumpf = union
{   
 #if (Cut_It=false)
  object { PlastikRumpfLinks }
 #end 
 object { PlastikRumpfRechts }
}

#declare Sitz = union
{
 union
 {
  difference
  {
   box { < -0.2, -0.45, -0.62 > < 0.2, 0.3, -0.15 > texture { SvenLeopard rotate < 0.0, 90.0, 0.0 > } }
   box 
   {
    < -0.3, 0.0, -1.0 > < 0.3, 2.0, 0.0 > 
    texture { SvenLeopard translate < 0.5, 0.0, 0.0 > } 
    rotate < 10.0, 0.0, 0.0 >
    translate < 0.0, -0.4, -0.3 > 
   }
  }
 }
 box 
 {
  < -0.2, 0.0, -0.30 > < 0.2, 0.001, 0.0 > 
  texture { SvenLeopard translate < 0.5, 0.0, 0.0 > rotate < 90.0, 0.0, 0.0 > } 
  rotate < 10.0, 0.0, 0.0 > 
  translate < 0.0, -0.4, -0.3 > 
 }      
 rotate < 0.0, 90.0, 9.0 >
 scale < 1.6, 1.25, 1.25 >
 translate < -0.55, -0.10, 0.0 >
}

#declare Skelett = difference
{
 union
 {
  cylinder { < -1.225, -0.70, -2.0 > < -1.225, -0.70, 2.0 > 0.025 }
  box { < -0.30, 0.35, -2.0 > < 3.0, 0.40, 2.0 > }
  box { < -1.25, -0.80, -2.0 > < 3.0, -0.75, 2.0 > }
  box { < -1.25, -2.0, -2.0 > < -1.20, -0.70, 2.0 > }
  box { < -1.60, -2.0, -0.15 > < -1.20, -1.27, 0.15 > } 
  difference
  {  
   union
   {
    box { < -0.30, -2.0, -0.85 > < 1.00, 2.0, -0.80 > } 
    box { < -0.30, -2.0, 0.80 > < 1.00, 2.0, 0.85 > } 
    box { < -0.30, -2.0, -1.25 > < 1.00, 2.0, -1.20 > } 
    box { < -0.30, -2.0, 1.20 > < 1.00, 2.0, 1.25 > } 
    box { < -0.30, -2.0, -1.45 > < 1.00, 2.0, -1.40 > } 
    box { < -0.30, -2.0, 1.40 > < 1.00, 2.0, 1.45 > } 
   }
   cylinder { < 0.0, 0.0, -2.0 > < 0.0, 0.0, 2.0 > 0.5 }
  } 
  difference
  { 
   union
   {
    cylinder { < -0.025, 0.0, 0.0 > < 0.025, 0.0, 0.0 > 2.0 translate < -0.3, 0.0, 0.0 > }
    cylinder { < -0.025, 0.0, 0.0 > < 0.025, 0.0, 0.0 > 2.0 translate < 0.3, 0.0, 0.0 > }
    cylinder { < -0.025, 0.0, 0.0 > < 0.025, 0.0, 0.0 > 2.0 translate < 0.9, 0.0, 0.0 > }
    cylinder { < -0.025, 0.0, 0.0 > < 0.025, 0.0, 0.0 > 2.0 translate < 1.5, 0.0, 0.0 > }
    cylinder { < -0.025, 0.0, 0.0 > < 0.025, 0.0, 0.0 > 2.0 translate < 2.1, 0.0, 0.0 > }
    box { < -0.30, -0.65, -2.0 > < 3.0, -0.60, 2.0 > }
    box { < -0.30, -0.45, -2.0 > < 3.0, -0.40, 2.0 > }
    box { < -0.30, 0.15, -2.0 > < 3.0, 0.20, 2.0 > }
   }
   cylinder { < 1.3, -0.2, 0.0 > < 5.0, -0.2, 0.0 > 0.6 }
   cylinder { < 0.35, -0.1, 0.0 > < 1.4, -0.1, 0.0 > 0.8 }
   cylinder { < 0.0, -0.15, 0.0 > < 0.4, -0.15, 0.0 > 0.9 }
   box { < -0.25, -2.00, -2.0 > < 0.25, 2.00, 2.0 > }
  }
 }
 cylinder { < -0.4, -1.0, 0.0 > < -0.2, -1.0, 0.0 > 0.3 scale < 1.0, 1.0, 1.5 > }
 object { InnenRumpf }
 texture { Halb }
}

#declare Panel1 = box
{
 < 0.0, 0.0, 0.0 > < 1.0, 1.0, 0.01 > 
// pigment { image_map { png "HeliChopper2Panel.png" } }
 pigment { rgb < 0.2, 0.2, 0.2 > }
 translate < -0.5, -0.5, 0.0 >
 scale < 2.0, 1.0, 1.0 >
 scale < 0.2, 0.2, 1.0 > 
} 

#declare Panel = union
{
 union
 {
  object { Panel1 } 
  box { < -0.2, -0.15, 0.001 > < 0.2, 0.1, 0.10 > pigment { Gray10 } finish { crand 0.1 } }  
  union
  {
   cylinder { < 0.0, -0.1, -0.1 > < 0.0, -0.1, 0.0 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   sphere { < 0.0, -0.1, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   cylinder { < 0.0, -0.1, -0.1 > < 0.3, -0.2, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   cylinder { < 0.0, -0.1, -0.1 > < -0.3, -0.2, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   sphere { < 0.3, -0.2, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   sphere { < -0.3, -0.2, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   cylinder { < 0.3, -0.2, -0.1 > < 0.3, 0.0, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   cylinder { < -0.3, -0.2, -0.1 > < -0.3, 0.0, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   sphere { < 0.3, 0.0, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   sphere { < -0.3, 0.0, -0.1 > 0.03 pigment { Gray10 } finish { crand 0.1 } }
   cylinder { < 0.3, -0.15, -0.1 > < 0.3, -0.01, -0.1 > 0.035 pigment { Gray30 } finish { crand 0.1 } }
   cylinder { < -0.3, -0.15, -0.1 > < -0.3, -0.01, -0.1 > 0.035 pigment { Gray30 } finish { crand 0.1 } }

   cylinder { < 0.30, -0.20, -0.10 > < 0.30, -0.05, -0.04 > 0.02 pigment { Gray30 } finish { crand 0.1 } }
   sphere { < 0.30, -0.05, -0.04 > 0.02 pigment { Gray30 } finish { crand 0.1 } }
   cylinder { < -0.30, -0.20, -0.10 > < -0.30, -0.05, -0.04 > 0.02 pigment { Gray30 } finish { crand 0.1 } }
   sphere { < -0.30, -0.05, -0.04 > 0.02 pigment { Gray30 } finish { crand 0.1 } }
  
   translate < 0.0, 0.1, 0.0 >
   rotate < 0.0, 0.0, 20.0 >
   translate < 0.0, -0.1, 0.0 >
  }
  rotate < 10.0, 0.0, 0.0 >
 }
 cylinder { < -0.15, -0.1, 0.1 > < 0.55, -0.1, 0.1 > 0.05 pigment { Gray10 } finish { crand 0.1 } }
 sphere { < 0.55, -0.1, 0.1 > 0.05 pigment { Gray10 } finish { crand 0.1 } }
 sphere { < -0.15, -0.1, 0.1 > 0.05 pigment { Gray10 } finish { crand 0.1 } }
 cylinder { < 0.40, -0.6, 0.1 > < 0.40, -0.1, 0.1 > 0.05 pigment { Gray10 } finish { crand 0.1 } }
 cylinder { < 0.40, -0.22, 0.1 > < 0.40, -0.20, 0.1 > 0.055 pigment { Black } finish { crand 0.1 } }
 cylinder { < 0.40, -0.25, 0.1 > < 0.40, -0.23, 0.1 > 0.055 pigment { Black } finish { crand 0.1 } }
 sphere { < 0.40, -0.6, 0.1 > 0.05 pigment { Gray10 } finish { crand 0.1 } }
 cylinder { < 0.50, -0.10, 0.10 > < 0.50, 0.05, -0.20 > 0.02 pigment { Gray10 } finish { crand 0.1 } }
 sphere { < 0.50, 0.05, -0.20 > 0.035 pigment { Gray30 } finish { crand 0.1 } }
 cylinder { < 0.40, -0.42, 0.1 > < 0.40, -0.40, 0.1 > 0.055 pigment { Black } finish { crand 0.1 } }
 cylinder { < 0.40, -0.45, 0.1 > < 0.40, -0.43, 0.1 > 0.055 pigment { Black } finish { crand 0.1 } }
 rotate < 0.0, -90.0, 0.0 >
 translate < 0.1, 0.0, -0.4 >
// case 
     rotate < 0.0, -00.0, 0.0 >
 translate < -0.1, 0.0, 0.4 >
} 

#declare Radio = union
{
 box
 {
  < 0.0, 0.0, -0.026 > < 1.0, 1.0, 0.01 > 
//  pigment { image_map { png "HeliChopper2Radio.png" } }
  pigment { rgb < 0.2, 0.2, 0.2 > }
  scale < 0.3, 0.1, 1.0 >
 }
 box
 {
  < 0.0, 0.0, -0.025 > < 1.0, 1.0, 0.10 > 
  pigment { Gray10 } finish { crand 0.1 } 
  scale < 0.3, 0.1, 1.0 >
 }
 cylinder { < -0.1, 0.0, 0.0 > < 0.3, 0.0, 0.0 > 0.025 pigment { Gray10 } finish { crand 0.1 } }
 sphere { < 0.3, 0.0, 0.05 > 0.05 pigment { Gray10 } finish { crand 0.1 } }
 scale 1.2
 rotate < 20.0, 0.0, 0.0 >
 translate < 0.1, 0.0, 0.0 >
  // case 1 
    rotate < 0.0, -20.0, 0.0 >
 translate < -0.1, 0.0, 0.0 >
} 

#declare Cockpit = difference
{
 union
 {
  box { < -1.75, -1.27, -0.25 > < -1.25, -1.22, 0.25 > pigment { Gray10 } finish { crand 0.1 } }
  cylinder { < -1.75, -1.27, 0.0 > < -1.75, -1.22, 0.0 > 0.25 pigment { Gray10 } finish { crand 0.1 } }
  difference
  {
   union
   {
    cylinder { < -1.75, 0.0, 0.0 > < -1.25, 0.0, 0.0 > 0.25 }
    sphere { < -1.75, 0.0, 0.0 > 0.25 }
   }
   box { < -2.2, 0.0, -0.2 > < -0.4, 0.3, 0.2 > }
   scale < 1.0, 0.5, 1.0 >
   translate < 0.0, -1.27, 0.0 >
   pigment { Gray10 }
   finish { crand 0.1 } 
  }
  object { Sitz rotate < 0.0, 0.0, -10.0 > translate < 0.2, -0.25, 0.0 > }
  object { Panel translate < -1.3, -0.25, 0.0 > }
  object { Radio translate < -1.3, -0.55, 0.4 > }
  union
  {
   box { < -1.40, -0.90, 0.30 > < -1.25, -0.80, 0.50 > }
   cylinder { < -1.40, -0.90, 0.40 > < -1.40, -0.80, 0.40 > 0.10 }
   cylinder { < -1.40, -0.90, 0.40 > < -1.25, -0.90, 0.40 > 0.10 }
   sphere { < -1.40, -0.90, 0.40 > 0.10 }
   pigment { Gray10 }
   finish { crand 0.1 } 
  }
 }
 object { InnenRumpf texture { Halb } }
}

#declare CockpitLight = light_source 
{
 < -0.6, 0.5, 0.0 >
 color Gray10       // light's color
 jitter              // adds random softening of light
 orient              // orient light
 fade_distance 1.0
 fade_power 1.0
 photons        // photon block for an object
 {  
  refraction on
  reflection on
 }
}


#declare RotorblattBulk = difference
{
 torus { 1.0, 0.1 rotate < 90.0, 0.0, 0.0 > }
 box { < 0.0, -3.0, -0.2 > < 3.0, 3.0, 0.2 > }
 box { < -3.0, -3.0, -0.2 > < 3.0, 0.0, 0.2 > }
 box { < -3.0, -3.0, -0.2 > < 0.0, 3.0, 0.2 > rotate < 0.0, 0.0, 60.0 > }
 translate < 0.0, -1.0, 0.0 >
 scale < 2.9, 0.2, 2.9 >
}                               

#declare RotorblattV = object
{
 RotorblattBulk
 texture { BlattV translate < -2.3, 0.0, 0.0 > scale 1.0 }  
 translate < -0.2, 0.0, 0.0 > 
}

#declare RotorRight = union
{
 object { RotorblattV rotate < 20.0, 090.0, 0.0 > }
 object { RotorblattV rotate < 20.0, 210.0, 0.0 > }
 object { RotorblattV rotate < 20.0, 330.0, 0.0 > }
 union
 {
  cylinder { < -0.30,  0.0, 0.0 > < 0.0, 0.0, 0.0 > 0.1 rotate < 0.0, 090.0, 0.0 > } 
  cylinder { < -0.30,  0.0, 0.0 > < 0.0, 0.0, 0.0 > 0.1 rotate < 0.0, 210.0, 0.0 > } 
  cylinder { < -0.30,  0.0, 0.0 > < 0.0, 0.0, 0.0 > 0.1 rotate < 0.0, 330.0, 0.0 > } 
  sphere { < -0.30,  0.0, 0.0 > 0.1 rotate < 0.0, -090.0, 0.0 > } 
  sphere { < -0.30,  0.0, 0.0 > 0.1 rotate < 0.0, -210.0, 0.0 > } 
  sphere { < -0.30,  0.0, 0.0 > 0.1 rotate < 0.0, -330.0, 0.0 > } 
 
  cylinder { < 0.0,  0.12, 0.0 > < 0.0, 0.22, 0.0 > 0.25 } 
  cylinder { < 0.0, -0.10, 0.0 > < 0.0, 0.10, 0.0 > 0.25 } 
  cylinder { < 0.0, -0.52, 0.0 > < 0.0, -0.12, 0.0 > 0.25 } 
  cylinder { < 0.0, -0.62, 0.0 > < 0.0, -0.55, 0.0 > 0.25 } 
  pigment { Gray30 }
  finish { Glossy }
 }
 cylinder { < 0.0, -1.0, 0.0 > < 0.0, 0.2, 0.0 > 0.2 texture { Chrome_Texture } } 
 cylinder { < 0.0, -1.0, 0.0 > < 0.0, -0.7, 0.0 > 0.201 pigment { Gray30 } finish { Glossy } } 
 sphere { < 0.0, 0.0, 0.0 > 0.25 scale < 1.0, 0.5, 1.0 > translate < 0.0, 0.22, 0.0 > texture { Chrome_Texture } }
 rotate < 0.0, (-clock*(360*0))-10, 0.0 > 
 translate < 0.0, 1.2, 0.0 >
 rotate < 7.0, 0.0, 20.0 > 
 translate < -0.0, 0.0, 1.55 >  
}

#declare RotorLeft = union
{
 object { RotorblattV rotate < -20.0, 090.0, 0.0 > }
 object { RotorblattV rotate < -20.0, 210.0, 0.0 > }
 object { RotorblattV rotate < -20.0, 330.0, 0.0 > }
 union
 {   
  cylinder { < -0.30,  0.0, 0.0 > < 0.0, 0.0, 0.0 > 0.1 rotate < 0.0, 090.0, 0.0 > } 
  cylinder { < -0.30,  0.0, 0.0 > < 0.0, 0.0, 0.0 > 0.1 rotate < 0.0, 210.0, 0.0 > } 
  cylinder { < -0.30,  0.0, 0.0 > < 0.0, 0.0, 0.0 > 0.1 rotate < 0.0, 330.0, 0.0 > } 
  sphere { < -0.30,  0.0, 0.0 > 0.1 rotate < 0.0, 090.0, 0.0 > } 
  sphere { < -0.30,  0.0, 0.0 > 0.1 rotate < 0.0, 210.0, 0.0 > } 
  sphere { < -0.30,  0.0, 0.0 > 0.1 rotate < 0.0, 330.0, 0.0 > } 
 
  cylinder { < 0.0,  0.12, 0.0 > < 0.0, 0.22, 0.0 > 0.25 } 
  cylinder { < 0.0, -0.10, 0.0 > < 0.0, 0.10, 0.0 > 0.25 } 
  cylinder { < 0.0, -0.52, 0.0 > < 0.0, -0.12, 0.0 > 0.25 } 
  cylinder { < 0.0, -0.62, 0.0 > < 0.0, -0.55, 0.0 > 0.25 } 
  pigment { Gray30 }
  finish { Glossy }
 }
 cylinder { < 0.0, -1.0, 0.0 > < 0.0, 0.2, 0.0 > 0.2 texture { Chrome_Texture } } 
 cylinder { < 0.0, -1.0, 0.0 > < 0.0, -0.7, 0.0 > 0.201 pigment { Gray30 } finish { Glossy } } 
 sphere { < 0.0, 0.0, 0.0 > 0.25 scale < 1.0, 0.5, 1.0 > translate < 0.0, 0.22, 0.0 > texture { Chrome_Texture } }
 rotate < 0.0, (clock*(360*5))+10, 0.0 >
 translate < 0.0, 1.2, 0.0 >
 rotate < -7.0, 0.0, 20.0 >
 translate < -0.0, 0.0, -1.55 >  
}
      
#declare Rad = union
{
 torus { 0.1, 0.05 pigment { Gray05 } }
 cylinder { < 0.0, -0.02, 0.0 > < 0.0, 0.02, 0.0 > 0.1 pigment { Gray95 } }
 rotate < 90.0, 0.0, 0.0 > 
 scale < 1.0, 1.0, 1.0 > 
} 

#declare Stand = union
{  
 difference       
 {
  cone 
  {
   < 0.5, 0.0, 0.0 > 0.30 < 0.0, -1.1, 0.0 > 0.20 
   scale < 1.3, 1.0, 0.35 >  
  }
  box { < -1.2, -1.1, -0.1 > < 1.1, -1.3, 0.1 > }
  pigment
  {  
   gradient y
   pigment_map 
   {
    [ 0.00 Gray95 ]
    [ 0.20 Gray95 ]
    [ 0.20 Gray95 ]
    [ 0.75 Gray30 ]
    [ 0.75 Gray30 ]
    [ 1.00 Gray30 ]
   }
   translate < 0.0, -0.7, 0.0 >
   scale 3.0 
   rotate < 0.0, 0.0, 5.0 >
   translate < 0.0, -0.0, 0.0 >
  }
  finish { Glossy } 
 }
 cylinder { < -1.2, -1.1, 0.0 > < 1.1, -1.1, 0.0 > 0.075 pigment { Gray50 } finish { Glossy } }
 sphere { < -1.2, -1.1, 0.0 > 0.075 pigment { Gray50 } finish { Glossy } }
 sphere { < 1.1, -1.1, 0.0 > 0.075 pigment { Gray50 } finish { Glossy } }

 cylinder { < -0.4, -0.6, 0.0 > < 0.0, -0.6, 0.0 > 0.03 pigment { Gray50 } finish { Glossy } }
 sphere { < -0.4, -0.6, 0.0 > 0.03 pigment { Gray50 } finish { Glossy } }
}
  
#declare Kufen = difference
{
 union  
 {                       
  object { Stand rotate < -20.0, 0.0, 0.0 > translate < -0.7, -0.6, 1.0 > }
  object { Stand rotate < 20.0, 0.0, 0.0 > translate < -0.7, -0.6, -1.0 > }
 }
 object { AussenRumpf }
}  
  
#declare Fahrwerk = union
{
 object { Rad translate < 0.7, -0.95, 0.0 > }
 object { Rad scale < 1.5, 1.5, 1.0 > translate < -1.0, -1.5, 0.5 > }
 object { Rad scale < 1.5, 1.5, 1.0 > translate < -1.0, -1.5, -0.5 > }
}   

#declare BugAntenne = union
{
 difference
 {
  sphere { < 0.0, 0.0, 0.0 > 0.1 scale < 2.0, 1.0, 1.0 > translate < -1.4, -1.6, 0.0 > pigment { Gray90 } finish { Glossy } } 
  object { AussenRumpf }
 }
 cylinder { < -3.0, -1.45, 0.0 > < -1.4, -1.63, 0.0 > 0.01 texture { Chrome_Texture } }
 box { < -2.95, -1.455, -0.075 > < -2.90, -1.445, 0.075 > texture { Chrome_Texture } }
 translate < 0.0, 0.0, 0.0 >
}  

#declare OberAntennen = union
{
 cylinder { < 0.0, 0.0, 0.0 > < 0.05, 0.3, 0.0 > 0.025 scale < 2.0, 1.0, 0.3 > translate < 0.0, 0.0, 0.2 > }
 cylinder { < 0.0, 0.0, 0.0 > < 0.05, 0.3, 0.0 > 0.025 scale < 2.0, 1.0, 0.3 > translate < 0.0, 0.0, -0.2 > }
 translate < -0.5, 0.75, 0.0 >
 pigment { Gray70 }
 finish { Glossy }
}
      
#declare UnterAntennen = union
{
 cylinder { < 0.0, 0.0, 0.0 > < 0.05, 0.3, 0.0 > 0.025 scale < 2.0, 1.0, 0.3 > translate < 0.0, 0.0, 0.2 > }
 cylinder { < 0.0, 0.0, 0.0 > < 0.05, 0.3, 0.0 > 0.025 scale < 2.0, 1.0, 0.3 > translate < 0.0, 0.0, -0.2 > }
 translate < -0.5, 0.75, 0.0 >
 pigment { Gray70 }
 finish { Glossy }
}
      
#declare PreHeliChopper2 = union
{
 object { Skelett }        // 
// object { Fahrwerk }        
 object { Kufen }          //  
 object { PlastikRumpf }   //
 object { GlasRumpf }      //
 object { TuerScharnier }  //    
 #if (Cut_It=false) object { TuerLinks } #end   //  
 object { TuerRechts }     // 
 object { Cockpit }        //
 object { CockpitLight }   //
 object { BugAntenne }     // 
 object { OberAntennen }   //   
 object { RotorRight }     // 
 object { RotorLeft }      // 
}

#declare HeliChopperTeam = union
{
 object { PreHeliChopper2 scale 0.8 }
// object { Human_Man_Afro_Bald_02 rotate < 0.0, 90.0, 0.0 > translate < -1.0, -1.0, 0.0 > rotate < 0.0, 0.0, -10.0 > translate < 0.2, -0.25, 0.0 > }
}

#declare HeliChopper02 = object 
{
 HeliChopperTeam 
 translate < 0.0, 2.0, 0.0 > 
// translate < 29.0-(100*clock), 2.0, 0.0 > 
 /* rotate < 0.0, clock*360.0, 0.0 >*/ 
 
// rotate < -20.0, -45.0, 20.0 >       Rotor animation
// rotate < 0.0, -0.0, 0.0 >        Normal Views
 translate < 0.0, -0.65, 0.0 > //  Airport View
} 
//object { HeliChopper02 rotate < -20.0, -40.0, 0.0 > }        
//object { HeliChopper02 rotate < 0.0, 90.0, 0.0 > translate < 0.0, 10.0, 0.0 > }    // 10 m over ground
object { HeliChopper02 rotate < 0.0, 60.0, 0.0 > translate < -12.0, 0.0, -10.0 > }    // on ground
/*  */
object { HeliChopper02 translate < -7.5, 0.0, -15.0 > }
object { HeliChopper02 translate < -7.5, 0.0, -07.5 > }
object { HeliChopper02 translate < -7.5, 0.0, 0.0 > }
object { HeliChopper02 translate < -7.5, 0.0, 07.5 > }
object { HeliChopper02 translate < -7.5, 0.0, 15.0 > }

object { HeliChopper02 translate < 0.0, 0.0, -15.0 > }
object { HeliChopper02 translate < 0.0, 0.0, -07.5 > }
object { HeliChopper02 translate < 0.0, 0.0, 0.0 > }
object { HeliChopper02 translate < 0.0, 0.0, 07.5 > }
object { HeliChopper02 translate < 0.0, 0.0, 15.0 > }

object { HeliChopper02 translate < 7.5, 0.0, -15.0 > }
object { HeliChopper02 translate < 7.5, 0.0, -07.5 > }
object { HeliChopper02 translate < 7.5, 0.0, 0.0 > }
object { HeliChopper02 translate < 7.5, 0.0, 07.5 > }
object { HeliChopper02 translate < 7.5, 0.0, 15.0 > }

//object { HeliChopper02 rotate < 20.0, 40.0, 0.0 > translate < 0.0, 10.0, 10.0 > }  //   
#declare AfroSkin1 = texture { pigment { rgb < 0.529, 0.396, 0.263 > } } 
#declare Shirt1 = texture { pigment { White } } 
#declare Shirt2 = texture { pigment { rgb < 0.494, 0.506, 0.612 > } finish { crand 0.3 } } 
#declare Trouser1 = texture { pigment { Wheat } } 
#declare Trouser2 = texture { pigment { rgb < 0.282, 0.294, 0.467 > } finish { crand 0.3 } } 
#declare Shoe1 = texture { pigment { BakersChoc } } 
#declare Shoe2 = texture { pigment { rgb < 0.667, 0.639, 0.541 > } } 
#declare Eye3 = texture { pigment { White } finish { Glossy } } 
#declare Hair3 = texture { pigment { Black } finish { Glossy } } 

// object { Human_Man_Afro_Bald_01(AfroSkin1,Shirt1,Shirt1,Trouser1,Trouser1,Shoe1) rotate < 0.0, 70.0, 0.0 > translate < -10.3, 0.0, 0.0 > }
// object { Human_Man_Afro_Bald_01(AfroSkin1,Shirt2,AfroSkin1,Trouser2,Trouser2,Shoe2) rotate < 0.0, -20.0, 0.0 > translate < -3.7, 0.0, -7.0 > }
// object { Human_Woman_Afro_Long_01(Hair3,Eye3,AfroSkin1,AfroSkin1,AfroSkin1,AfroSkin1,AfroSkin1,AfroSkin1,AfroSkin1,Gold_Texture,Gold_Texture,AfroSkin1,Gold_Texture) rotate < 0.0, 20.0, 0.0 > translate < -5.0, 0.0, 0.0 > }
//plane { y, 0.0 pigment { rgb < 0.8431373,  0.8352941,  0.7411765 > } finish { crand 0.3 } }   //   grass  
plane { y, 0.0 pigment { rgb < 1,  1,  1 > } finish { crand 0.0 } }   //  
background { rgb < 0.6039216,  0.7921569,  0.9058824 > }   
/*
sky_sphere                                    
{
 pigment 
 {
  gradient y
  color_map 
  {
 #switch(Zeit)
  #range(00,04)
   [ 0.0 Black ]
   [ 0.7 MidnightBlue ]
  #break 
  #case(05)
   [ 0.0 Salmon ]
   [ 0.7 rgb < 0.5, 0.35, 0.2 > ]
  #break 
  #case(06)
   [ 0.0 rgb < 0.5, 0.35, 0.2 > ]
   [ 0.7 rgb < 0.3, 0.3, 0.4 > ]
  #break 
  #case(07)
   [ 0.0 rgb < 0.33, 0.3, 0.4 > ]
   [ 0.7 rgb < 0.1, 0.1, 0.3 > ]
  #break 
  #case(08)
   [ 0.0 rgb < 0.05, 0.1, 0.3 > ]
   [ 0.7 rgb < 0.1, 0.2, 0.8 > ]
  #break 
  #case(09)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(10)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(11)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(12)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(13)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(14)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(15)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(16)
   [ 0.0 rgb < 0.1, 0.2, 0.8 > ]
   [ 0.7 rgb < 0.0, 0.0, 0.2 > ]
  #break 
  #case(17)
   [ 0.0 rgb < 0.6, 0.5, 0.4 > ]
   [ 0.7 rgb < 0.1, 0.2, 0.8 > ]
  #break 
  #case(18)
   [ 0.0 rgb < 0.5, 0.3, 0.2 > ]
   [ 0.7 rgb < 0.95, 0.3, 0.15 > ]
  #break 
  #case(19)
   [ 0.0 MidnightBlue ]
   [ 0.7 rgb < 0.5, 0.3, 0.2 > ]      
  #break 
  #range(20,24)
   [ 0.0 Black ]
   [ 0.7 MidnightBlue ]
  #break 
 #end 
  }  
  translate < 0.0, -0.5, 0.0 >
  scale 2.0 
 #switch(Zeit)
  #range(00,04)
   rotate < -40, 64.0, -64.0 >
  #break 
  #case(05)
   rotate < -40, -55.0, -55.0 >
  #break 
  #case(06)
   rotate < -40.0, -48.0, -48.0 >
  #break 
  #case(07)
   rotate < -40, -40.0, -40.0 >
  #break 
  #case(08)
   rotate < -40, -32.0, -32.0 >
  #break 
  #case(09)
   rotate < -40, -24.0, -24.0 >
  #break 
  #case(10)
   rotate < -40, -16.0, -16.0 >
  #break 
  #case(11)
   rotate < -40, -08.0, -08.0 >
  #break 
  #case(12)
   rotate < -40, -00.0, 0.0 >
  #break 
  #case(13)
   rotate < -40, 08.0, 08.0 >
  #break 
  #case(14)
   rotate < -40, 16.0, 16.0 >
  #break 
  #case(15)
   rotate < -40, 24.0, 24.0 >
  #break 
  #case(16)
   rotate < -40, 32.0, 32.0 >
  #break 
  #case(17)
   rotate < -40, 40.0, 40.0 >
  #break 
  #case(18)
   rotate < -40, 48.0, 48.0 >
  #break 
  #case(19)
   rotate < -40, 55.0, 55.0 >
  #break 
  #range(20,24)
   rotate < -40, 64.0, 64.0 >
  #break 
 #end 
 rgb < 0.7058824,  0.7882353,  0.8705882 >
 }
}   
*/ 
//cylinder { < 0.0, -1.0, 0.0 > < 0.0, 0.0, 0.0 > 10.0 pigment { ForestGreen } }              //
//cylinder { < 2.0, 0.0, 0.0 > < 2.0, 1.7, 0.0 > 0.1 pigment { Yellow } }






